Long: random-file
Arg: <file>
Help: File for reading random data from
Category: misc
Example: --random-file rubbish $URL
Added: 7.7
See-also: egd-file
---
Specify the path name to file containing what will be considered as random
data. The data may be used to seed the random engine for SSL connections. See
also the --egd-file option.
