Long: sasl-ir
Help: Enable initial response in SASL authentication
Added: 7.31.0
Category: auth
Example: --sasl-ir imap://example.com/
See-also: sasl-authzid
---
Enable initial response in SASL authentication.
