Long: proxy-service-name
Arg: <name>
Help: SPNEGO proxy service name
Added: 7.43.0
Category: proxy tls
Example: --proxy-service-name "shrubbery" -x proxy $URL
See-also: service-name proxy
---
This option allows you to change the service name for proxy negotiation.
