Long: proxy-tlspassword
Arg: <string>
Help: TLS password for HTTPS proxy
Added: 7.52.0
Category: proxy tls auth
Example: --proxy-tlspassword passwd -x https://proxy $URL
See-also: proxy proxy-tlsuser
---
Same as --tlspassword but used in HTTPS proxy context.
