Long: proxy-cert-type
Arg: <type>
Added: 7.52.0
Help: Client certificate type for HTTPS proxy
Category: proxy tls
Example: --proxy-cert-type PEM --proxy-cert file -x https://proxy $URL
See-also: proxy-cert
---
Same as --cert-type but used in HTTPS proxy context.
