Long: proxy-tlsv1
Help: Use TLSv1 for HTTPS proxy
Added: 7.52.0
Category: proxy tls auth
Example: --proxy-tlsv1 -x https://proxy $URL
See-also: proxy
---
Same as --tlsv1 but used in HTTPS proxy context.
