Short: 0
Long: http1.0
Tags: Versions
Protocols: HTTP
Added: 7.9.1
Mutexed: http1.1 http2
Help: Use HTTP 1.0
Category: http
Example: --http1.0 $URL
See-also: http0.9 http1.1
---
Tells curl to use HTTP version 1.0 instead of using its internally preferred
HTTP version.
