Long: http1.1
Tags: Versions
Protocols: HTTP
Added: 7.33.0
Mutexed: http1.0 http2
Help: Use HTTP 1.1
Category: http
Example: --http1.1 $URL
See-also: http1.1 http0.9
---
Tells curl to use HTTP version 1.1.
