Long: proxy-key
Help: Private key for HTTPS proxy
Arg: <key>
Category: proxy tls
Example: --proxy-key here -x https://proxy $URL
Added: 7.52.0
See-also: proxy-key-type proxy
---
Same as --key but used in HTTPS proxy context.
