Long: proxy-tlsuser
Arg: <name>
Help: TLS username for HTTPS proxy
Added: 7.52.0
Category: proxy tls auth
Example: --proxy-tlsuser smith -x https://proxy $URL
See-also: proxy proxy-tlspassword
---
Same as --tlsuser but used in HTTPS proxy context.
