Long: metalink
Help: Process given URLs as metalink XML file
Added: 7.27.0
Category: misc
Example: --metalink file $URL
See-also: parallel
---
This option was previously used to specify a metalink resource. Metalink
support has been disabled in curl since 7.78.0 for security reasons.
