Long: help
Arg: <category>
Short: h
Help: Get help for commands
Category: important curl
Example: --help all
Added: 4.0
See-also: verbose
---
Usage help. This lists all commands of the <category>.
If no arg was provided, curl will display the most important
command line arguments.
If the argument "all" was provided, curl will display all options available.
If the argument "category" was provided, curl will display all categories and
their meanings.
