Long: data-ascii
Arg: <data>
Help: HTTP POST ASCII data
Protocols: HTTP
Category: http post upload
Example: --data-ascii @file $URL
Added: 7.2
See-also: data-binary data-raw data-urlencode
---
This is just an alias for --data.
