Long: trace-time
Help: Add time stamps to trace/verbose output
Added: 7.14.0
Category: verbose
Example: --trace-time --trace-ascii output $URL
See-also: trace verbose
---
Prepends a time stamp to each trace or verbose line that curl displays.

This option is global and does not need to be specified for each use of
--next.
